<?php

namespace Sit\Destinations\Policies;

use Litepie\User\Contracts\UserPolicy;
use Sit\Destinations\Models\DestinationCategory;

class DestinationCategoryPolicy
{

    /**
     * Determine if the given user can view the destination_category.
     *
     * @param UserPolicy $user
     * @param DestinationCategory $destination_category
     *
     * @return bool
     */
    public function view(UserPolicy $user, DestinationCategory $destination_category)
    {
        if ($user->canDo('destinations.destination_category.view') && $user->isAdmin()) {
            return true;
        }

        return $destination_category->user_id == user_id() && $destination_category->user_type == user_type();
    }

    /**
     * Determine if the given user can create a destination_category.
     *
     * @param UserPolicy $user
     * @param DestinationCategory $destination_category
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('destinations.destination_category.create');
    }

    /**
     * Determine if the given user can update the given destination_category.
     *
     * @param UserPolicy $user
     * @param DestinationCategory $destination_category
     *
     * @return bool
     */
    public function update(UserPolicy $user, DestinationCategory $destination_category)
    {
        if ($user->canDo('destinations.destination_category.edit') && $user->isAdmin()) {
            return true;
        }

        return $destination_category->user_id == user_id() && $destination_category->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given destination_category.
     *
     * @param UserPolicy $user
     * @param DestinationCategory $destination_category
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, DestinationCategory $destination_category)
    {
        return $destination_category->user_id == user_id() && $destination_category->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given destination_category.
     *
     * @param UserPolicy $user
     * @param DestinationCategory $destination_category
     *
     * @return bool
     */
    public function verify(UserPolicy $user, DestinationCategory $destination_category)
    {
        if ($user->canDo('destinations.destination_category.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given destination_category.
     *
     * @param UserPolicy $user
     * @param DestinationCategory $destination_category
     *
     * @return bool
     */
    public function approve(UserPolicy $user, DestinationCategory $destination_category)
    {
        if ($user->canDo('destinations.destination_category.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
