<?php

namespace Sit\Destinations\Policies;

use Litepie\User\Contracts\UserPolicy;
use Sit\Destinations\Models\Destination;

class DestinationPolicy
{

    /**
     * Determine if the given user can view the destination.
     *
     * @param UserPolicy $user
     * @param Destination $destination
     *
     * @return bool
     */
    public function view(UserPolicy $user, Destination $destination)
    {
        if ($user->canDo('destinations.destination.view') && $user->isAdmin()) {
            return true;
        }

        return $destination->user_id == user_id() && $destination->user_type == user_type();
    }

    /**
     * Determine if the given user can create a destination.
     *
     * @param UserPolicy $user
     * @param Destination $destination
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('destinations.destination.create');
    }

    /**
     * Determine if the given user can update the given destination.
     *
     * @param UserPolicy $user
     * @param Destination $destination
     *
     * @return bool
     */
    public function update(UserPolicy $user, Destination $destination)
    {
        if ($user->canDo('destinations.destination.edit') && $user->isAdmin()) {
            return true;
        }

        return $destination->user_id == user_id() && $destination->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given destination.
     *
     * @param UserPolicy $user
     * @param Destination $destination
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Destination $destination)
    {
        return $destination->user_id == user_id() && $destination->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given destination.
     *
     * @param UserPolicy $user
     * @param Destination $destination
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Destination $destination)
    {
        if ($user->canDo('destinations.destination.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given destination.
     *
     * @param UserPolicy $user
     * @param Destination $destination
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Destination $destination)
    {
        if ($user->canDo('destinations.destination.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
