<?php

namespace Sit\Destinations\Providers;

use Illuminate\Support\ServiceProvider;

class DestinationsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'destinations');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'destinations');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerDestinations();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerDestinations()
    {
        $this->app->bind('destinations', function($app) {
            return new Destinations($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Destinations', 'Lavalite\Destinations\Facades\Destinations');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('sit.destinations', function ($app) {
            return $this->app->make('Sit\Destinations\Destinations');
        });

        // Bind Destination to repository
        $this->app->bind(
            'Sit\Destinations\Interfaces\DestinationRepositoryInterface',
            \Sit\Destinations\Repositories\Eloquent\DestinationRepository::class
        );
        // Bind DestinationCategory to repository
        $this->app->bind(
            'Sit\Destinations\Interfaces\DestinationCategoryRepositoryInterface',
            \Sit\Destinations\Repositories\Eloquent\DestinationCategoryRepository::class
        );

        $this->app->register(\Sit\Destinations\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Sit\Destinations\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and destinations's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/destinations.php', 'destinations'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeDestinations::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['sit.destinations'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('sit/destinations.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/destinations')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/destinations')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
